@@ -23,6 +23,7 @@ describe 'glance::api' do
       :purge_config                   => false,
       :delayed_delete                 => '<SERVICE DEFAULT>',
       :scrub_time                     => '<SERVICE DEFAULT>',
+      :enforce_secure_rbac            => '<SERVICE DEFAULT>',
       :image_cache_dir                => '/var/lib/glance/image-cache',
       :image_import_plugins           => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
@@ -30,6 +31,7 @@ describe 'glance::api' do
       :ignore_user_roles              => '<SERVICE DEFAULT>',
       :enabled_import_methods         => '<SERVICE DEFAULT>',
       :node_staging_uri               => '<SERVICE DEFAULT>',
+      :worker_self_reference_url      => '<SERVICE DEFAULT>',
       :image_member_quota             => '<SERVICE DEFAULT>',
       :image_cache_stall_time         => '<SERVICE DEFAULT>',
       :image_cache_max_size           => '<SERVICE DEFAULT>',
@@ -64,6 +66,7 @@ describe 'glance::api' do
         :location_strategy              => 'store_type',
         :delayed_delete                 => 'true',
         :scrub_time                     => '10',
+        :enforce_secure_rbac            => 'true',
         :image_cache_dir                => '/tmp/glance',
         :image_import_plugins           => 'image_conversion',
         :image_conversion_output_format => 'raw',
@@ -71,6 +74,7 @@ describe 'glance::api' do
         :ignore_user_roles              => 'admin',
         :enabled_import_methods         => 'glance-direct,web-download',
         :node_staging_uri               => '/tmp/staging',
+        :worker_self_reference_url      => 'http://worker1',
         :image_member_quota             => '128',
         :image_cache_stall_time         => '10',
         :image_cache_max_size           => '10737418240',
@@ -123,11 +127,13 @@ describe 'glance::api' do
             'location_strategy',
             'delayed_delete',
             'scrub_time',
+            'enforce_secure_rbac',
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
             'cache_prefetcher_interval',
             'node_staging_uri',
+            'worker_self_reference_url',
             'image_member_quota',
             'limit_param_default',
             'api_limit_max',
@@ -189,7 +195,8 @@ describe 'glance::api' do
           is_expected.to contain_glance_api_config('DEFAULT/key_file').with_value('<SERVICE DEFAULT>')
         end
 
-        it 'is_expected.to have no disk_formats set' do
+        it 'is_expected.to have no formats set' do
+          is_expected.to contain_glance_api_config('image_format/container_formats').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('<SERVICE DEFAULT>')
         end
 
@@ -294,14 +301,30 @@ describe 'glance::api' do
       end
     end
 
-    describe 'with disk_formats option' do
+    describe 'with formats options with strings' do
       let :params do
         default_params.merge({
-          :disk_formats => 'raw,iso',
+          :container_formats => 'ami,ari',
+          :disk_formats      => 'raw,iso',
         })
       end
 
       context 'with disk_formats option' do
+        it { is_expected.to contain_glance_api_config('image_format/container_formats').with_value('ami,ari') }
+        it { is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('raw,iso') }
+      end
+    end
+
+    describe 'with formats options with arrays' do
+      let :params do
+        default_params.merge({
+          :container_formats => ['ami', 'ari'],
+          :disk_formats      => ['raw', 'iso'],
+        })
+      end
+
+      context 'with disk_formats option' do
+        it { is_expected.to contain_glance_api_config('image_format/container_formats').with_value('ami,ari') }
         it { is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('raw,iso') }
       end
     end
