@@ -4,6 +4,8 @@ describe 'glance::db::sync' do
 
   shared_examples_for 'glance-dbsync' do
 
+    it { is_expected.to contain_class('glance::deps') }
+
     it 'runs glance-manage db_sync' do
       is_expected.to contain_exec('glance-manage db_sync').with(
         :command     => 'glance-manage  db_sync',
@@ -12,6 +14,7 @@ describe 'glance::db::sync' do
         :refreshonly => 'true',
         :try_sleep   => 5,
         :tries       => 10,
+        :timeout     => 300,
         :logoutput   => 'on_failure',
         :subscribe   => ['Anchor[glance::install::end]',
                          'Anchor[glance::config::end]',
@@ -24,7 +27,8 @@ describe 'glance::db::sync' do
     describe "overriding extra_params" do
       let :params do
         {
-          :extra_params => '--config-file /etc/glance/glance.conf',
+          :extra_params    => '--config-file /etc/glance/glance.conf',
+          :db_sync_timeout => 750,
         }
       end
 
@@ -35,6 +39,7 @@ describe 'glance::db::sync' do
         :refreshonly => 'true',
         :try_sleep   => 5,
         :tries       => 10,
+        :timeout     => 750,
         :logoutput   => 'on_failure',
         :subscribe   => ['Anchor[glance::install::end]',
                          'Anchor[glance::config::end]',
